ASE development — ASE documentation

### Navigation

- index
- modules |

# ASE development

As a developer, you should subscribe to all ASE related Mailing Lists.

## Development topics

- Release notes
  - Development version in trunk
  - Version 3.9.0
  - Version 3.8.0
  - Version 3.7.0
  - Version 3.6.0
  - Version 3.5.1
  - Version 3.5.0
  - Version 3.4.1
- How to contribute
  - SVN access
  - Committers
- Using version control (SVN)
- Coding Conventions
  - Importing modules
  - Python Coding Conventions
  - General advice
  - Writing documentation in the code
  - Run pep8.py on your code
  - Run autopep8.py on your code
  - Using pylint to check your code
    - Running pylint yourself
  - Run epydoc on your code
- Writing documentation
  - Installing Docutils and Sphinx
  - Other requirements
  - Using Sphinx
  - Extensions to Sphinx
  - Running Python code to create figures
  - reStructedText in emacs
  - Updating Sphinx
  - Setting up development environment with Vagrant
- Adding new calculators
  - Description of base-classes
    - The Calculator base-class
    - The FileIOCalculator class
- Making movies
  - using recordmydesktop
  - using avconf to collect png files
- New release
- Testing the code
  - How to fail successfully
- Buildbot
  - Configuration of buildmaster
  - Installation and configuration of buildslaves
    - Installation
      - Fedora
      - OS X
      - RHEL5
      - RHEL6
      - RHEL7
      - Windows
    - Configuration
- Translate ASE
  - How to translate
  - Check and commit your translation
  - Maintaining translations
- To do
  - Documentation
  - Code
- Python 3 strategy
- ASE enhancement proposals
  - Calculator interface proposal
    - Behavior
    - Standards parameters
    - ABC calculator example
    - Implementation
    - Testing
  - Command line tools
    - Current status
    - Proposed set of command line tools
    - Comments
    - Naming convention
    - Implementation details

## Creating an encrypted password for SVN access

Use this command:

    htpasswd -nm <your-desired-user-name>

and type a good password twice. The encrypted password will be printed on the screen.

Alternatively, you can use:

    openssl passwd -apr1

followed by your password (twice).

### Navigation

- index
- modules |